Learn R Programming

BayesCR (version 2.0)

motorettes: Accelerated Life Tests On Electrical Insulation

Description

Accelerated life tests on electrical insulation in motorettes with censoring times.

Usage

data(motorettes)

Arguments

Format

A data frame with 40 observed times of life tests on electrical insulation in motorettes at four different temperatures (150C, 170c, 190c and 200c). y corresponds to log10 of the failure time (or end of study time, in case of right censored observations), x corresponds to (100/(temperature + 273.2)) and cc is a indicator of censoring (1 if censored, 0 if not).

Examples

Run this code
# NOT RUN {
##Load the data
data(motorettes)
attach(motorettes)

##Set design matrix
x <- cbind(1,x)

##Fits a right censored normal model
Normal <- Bayes.CR(cc,x,y,cens="right",dist="Normal",n.thin=10,burnin=200,n.iter=800,
n.chains=1,chain="TRUE")
# }

Run the code above in your browser using DataLab